/*
 * Copyright 2016 Google Inc. All Rights Reserved.
 *
 * This code is confidential and provided to Android partners under NDA. You may modify, compile and
 * distribute the compiled code with your management software to assist with the provisioning and
 * management of Android devices. Other uses require written permission.
 */
package com.google.android.apps.work.dpcsupport;

import android.app.admin.DevicePolicyManager;
import android.content.ComponentName;
import android.content.Context;
import android.os.Build;
import android.os.Build.VERSION_CODES;

/**
 * Helper class for interacting with {@link DevicePolicyManager}.
 */
class DevicePolicyManagerHelper {

  private final Context context;
  private final DevicePolicyManager devicePolicyManager;

  DevicePolicyManagerHelper(Context context) {
    this.context = context;
    this.devicePolicyManager =
        (DevicePolicyManager) context.getSystemService(Context.DEVICE_POLICY_SERVICE);
  }

  boolean isDeviceOwner() {
    if (Build.VERSION.SDK_INT >= VERSION_CODES.LOLLIPOP) {
      return devicePolicyManager.isDeviceOwnerApp(context.getPackageName());
    } else {
      return false;
    }
  }

  boolean isProfileOwner() {
    if (Build.VERSION.SDK_INT >= VERSION_CODES.LOLLIPOP) {
      return devicePolicyManager.isProfileOwnerApp(context.getPackageName());
    } else {
      return false;
    }
  }

  boolean isDeviceOrProfileOwner() {
    return isDeviceOwner() || isProfileOwner();
  }

  boolean isDeviceAdmin() {
    if (devicePolicyManager.getActiveAdmins() == null) {
      return false;
    }
    for (ComponentName componentName : devicePolicyManager.getActiveAdmins()) {
      if (componentName.getPackageName().equals(context.getPackageName())) {
        return true;
      }
    }
    return false;
  }
}
