package com.google.android.apps.work.dpcsupport;

import android.accounts.Account;
import android.accounts.AccountManager;
import android.content.ContentResolver;
import android.content.Context;
import android.content.SyncAdapterType;
import android.util.Log;
import androidx.annotation.VisibleForTesting;
import com.google.android.gms.auth.GoogleAuthUtil;
import java.util.ArrayList;
import java.util.List;

/**
 * This helepr workarounds a bug that contact sync adapter (already fixed on new devices) crashes
 * when syncing an account with a non-email address name.
 */
public class DisableEnrollerAccountSyncHelper {
  @VisibleForTesting static final int NOT_SYNCABLE = 0;

  private final AccountManager accountManager;
  private final DevicePolicyManagerHelper devicePolicyManagerHelper;

  public DisableEnrollerAccountSyncHelper(Context context) {
    accountManager = (AccountManager) context.getSystemService(Context.ACCOUNT_SERVICE);
    devicePolicyManagerHelper = new DevicePolicyManagerHelper(context);
  }

  public void disableSyncIfNecessary() {
    if (!shouldDisableSync()) {
      return;
    }
    List<Account> enrollerAccounts = getEnrollerAccounts();
    if (enrollerAccounts.isEmpty()) {
      return;
    }
    Log.i(Constants.TAG, "Attempt to disable sync of enroller accounts");
    SyncAdapterType[] syncAdapterTypes = ContentResolver.getSyncAdapterTypes();
    for (SyncAdapterType syncAdapterType : syncAdapterTypes) {
      if (!GoogleAuthUtil.GOOGLE_ACCOUNT_TYPE.equals(syncAdapterType.accountType)) {
        continue;
      }
      for (Account account : enrollerAccounts) {
        Log.i(
            Constants.TAG,
            "Disabling account " + account.name + " from syncing " + syncAdapterType.authority);
        ContentResolver.setIsSyncable(account, syncAdapterType.authority, NOT_SYNCABLE);
      }
    }
  }

  private boolean shouldDisableSync() {
    return devicePolicyManagerHelper.isDeviceOwner();
  }

  private List<Account> getEnrollerAccounts() {
    Account[] accounts = accountManager.getAccountsByType(GoogleAuthUtil.GOOGLE_ACCOUNT_TYPE);
    List<Account> enrollerAccounts = new ArrayList<>();
    for (Account account : accounts) {
      if (account.name.contains("@")) {
        Log.w(Constants.TAG, "Skipping disable sync for non-enroller account: " + account.name);
      } else {
        enrollerAccounts.add(account);
      }
    }
    return enrollerAccounts;
  }
}
