/*
 * Copyright 2017 Google Inc. All Rights Reserved.
 *
 * This code is confidential and provided to Android partners under NDA. You may modify, compile and
 * distribute the compiled code with your management software to assist with the provisioning and
 * management of Android devices. Other uses require written permission.
 */
package com.google.android.apps.work.dpcsupport;

import android.os.Handler;
import android.os.HandlerThread;
import java.util.concurrent.Executor;
import java.util.concurrent.RejectedExecutionException;

/**
 * Posts a {@link Runnable} on a {@link HandlerThread} then calls {@link HandlerThread#quitSafely()}
 * right away.
 */
class HandlerThreadExecutor implements Executor {

  @Override
  public void execute(Runnable runnable) throws NullPointerException, RejectedExecutionException {
    if (runnable == null) {
      throw new NullPointerException("Runnable cannot be null");
    }
    HandlerThread handlerThread = new HandlerThread(runnable.getClass().getName());
    handlerThread.start();
    Handler handler = new Handler(handlerThread.getLooper());
    handler.post(runnable);
    handlerThread.quitSafely();
  }
}
