/*
 * Copyright 2016 Google Inc. All Rights Reserved.
 *
 * This code is confidential and provided to Android partners under NDA. You may modify, compile and
 * distribute the compiled code with your management software to assist with the provisioning and
 * management of Android devices. Other uses require written permission.
 */
package com.google.android.apps.work.dpcsupport;

import android.accounts.Account;

/**
 * Callback for {@link AndroidForWorkAccountSupport#addAndroidForWorkAccount(String,
 * WorkAccountAddedCallback)}.
 */
public abstract class WorkAccountAddedCallback {

  /** Error codes to return to indicate that adding the Android for Work Account failed. */
  @SuppressWarnings("JavaLangClash") // go/javalangclash-lsc
  public enum Error {
    EMPTY_TOKEN,
    EXCEPTION_ADDING_ACCOUNT,

    /** A precondition of calling the method was not met. Detailed explanation is logged. */
    FAILED_PRECONDITION
  }

  /**
   * Called after the Android for Work Account is ready to use. This means that the account has
   * successfully been added to the account manager.
   *
   * @param account the account which has now been added to the device
   * @param deviceHint not used, it's always en empty string.
   */
  public abstract void onAccountReady(Account account, String deviceHint);

  /** Called if there was an error adding the Android for Work Account to the account manager. */
  public abstract void onFailure(Error error);

  /**
   * Called if there was an error adding the Android for Work Account to the account manager.
   *
   * @param error error code indicating the failure of adding the Android for Work account
   * @param throwable the throwable which caused the failure.
   */
  public void onFailure(Error error, Throwable throwable) {
    onFailure(error);
  }
}
