package com.google.android.apps.work.dpcsupport;

/**
 * Callback for {@link
 * AndroidForWorkAccountSupport#removeAllAndroidForWorkAccounts(WorkAccountsRemovedCallback)}.
 */
public abstract class WorkAccountsRemovedCallback {

  /** Error codes to return to indicate that removing the Android for Work accounts failed. */
  @SuppressWarnings("JavaLangClash") // go/javalangclash-lsc
  public enum Error {
    EXCEPTION_REMOVING_ACCOUNT,

    /** A precondition of calling the method was not met. Detailed explanation is logged. */
    FAILED_PRECONDITION
  }

  /** Called when all the Android for Work Accounts have been removed. */
  public abstract void onSuccess();

  /** Called if there was an error removing an Android for Work Account. */
  public abstract void onFailure(Error error);

  /**
   * Called if there was an error removing an Android for Work Account.
   *
   * @param error error code indicating the failure of removing Android for Work account
   * @param throwable the throwable which caused the failure.
   */
  public void onFailure(Error error, Throwable throwable) {
    onFailure(error);
  }
}
