/*
 * Copyright 2016 Google Inc. All Rights Reserved.
 *
 * This code is confidential and provided to Android partners under NDA. You may modify, compile and
 * distribute the compiled code with your management software to assist with the provisioning and
 * management of Android devices. Other uses require written permission.
 */
package com.google.android.apps.work.dpcsupport;

/**
 * Reports the results of the {@link AndroidForWorkAccountSupport} initialization.
 *
 * <p>One of either {@link #onSuccess} or {@link #onFailure} will be called exactly once.
 */
public abstract class WorkingEnvironmentCallback {

  /**
   * Error codes to return to indicate that initializing Android for Work Account support failed.
   */
  @SuppressWarnings("JavaLangClash") // go/javalangclash-lsc
  public enum Error {
    PLAY_STORE_NOT_FOUND,
    PLAY_STORE_OUTDATED,
    PLAY_STORE_DOWNLOAD_FAILED,
    PLAY_STORE_DOWNLOAD_TIMEOUT,
    PLAY_STORE_INSTALL_FAILED,
    PLAY_STORE_SIGNATURE_MISMATCH,
    PLAY_SERVICES_NOT_FOUND,
    PLAY_SERVICES_OUTDATED,
    PLAY_SERVICES_PACKAGE_UPDATE_FAILED,
    PLAY_SERVICES_SESSION_NOT_FOUND,
    PLAY_SERVICES_UPDATE_CONNECTION_FAILED,
    PLAY_SERVICES_UPDATE_REMOTE_FAILURE,
    PLAY_SERVICES_UPDATE_TIMEOUT,
    PLAY_SERVICES_UPDATE_FAILED_TO_START,
    FAILED_TO_CONNECT_TO_WORK_ACCOUNT_API,
    ENABLE_WORK_ACCOUNT_AUTHENTICATOR_TIMEOUT,
    FAILED_TO_REMOVE_ENROLLER_ACCOUNT,
    CHECKIN_TIMEOUT,
    CHECKIN_COMPLETE_BUT_NO_ANDROID_ID_FOUND,

    /** A precondition of calling the method was not met. Detailed explanation is logged. */
    FAILED_PRECONDITION,

    /** Unexpected exception. Detailed explanation is logged. */
    EXCEPTION,
  }

  /** Called when the device has support for Android for Work Accounts. */
  public abstract void onSuccess();

  /** Called if there was an error ensuring support for Android for Work Accounts. */
  public abstract void onFailure(Error statusCode);

  /**
   * Called if there was an error adding the Android for Work Account to the account manager.
   *
   * @param error error code indicating the stage at which initializing Android for Work account
   *     support failed.
   * @param throwable the throwable which caused the failure.
   */
  public void onFailure(Error error, Throwable throwable) {
    onFailure(error);
  }

  /**
   * Called when there is a change in the progress of ensuring support for Android for Work
   * Accounts. The value of progress is a value between 0 and 1 inclusive.
   */
  public void onProgressChange(float progress) {}
}
